@@ -79,6 +79,9 @@ model.list <- list()
 #'
 #' @param dose.units The units associated with the dose received.
 #'
+#'@param parameterize.args Additional parameters passed to parameterize function if 
+#'parameters is NULL.
+#'  
 #'@param ... Additional parameters passed to parameterize function if 
 #'parameters is NULL.
 #'  
@@ -405,6 +408,7 @@ calc_analytic_css <- function(chem.name=NULL,
           chem.cas = chem.cas,
           chem.name = chem.name,
           dtxsid=dtxsid,
+          species = species,
           parameters=parameters,
           dosing=dosing,
           dose.units=dose.units,
